import OpenAI from 'openai';

export type ChatMessage = OpenAI.Chat.Completions.ChatCompletionMessageParam;
export type ChatMessageOptions = Partial<OpenAI.Chat.Completions.ChatCompletionCreateParams> & {
  /**
   * 是否能够思考
   * 如果会话是千文，服务器的接口，默认为 true
   */
  enable_thinking?: boolean;
};
export type ChatMessageComplete = OpenAI.Chat.Completions.ChatCompletion;
export type ChatMessageStream = OpenAI.Chat.Completions.ChatCompletion;

export type EmbeddingMessage = Partial<OpenAI.Embeddings.EmbeddingCreateParams>;
export type EmbeddingMessageComplete = OpenAI.Embeddings.CreateEmbeddingResponse;
export interface BaseChatInterface {
  chat(messages: ChatMessage[], options?: ChatMessageOptions): Promise<ChatMessageComplete>;
}

export interface BaseChatUsageInterface {
  /**
   * 提示词令牌
   */
  prompt_tokens: number;
  /**
   *  总令牌
   */
  total_tokens: number;
  /**
   * 完成令牌
   */
  completion_tokens: number;
}

export type ChatStream = AsyncGenerator<ChatMessageComplete, void, unknown>;
